@@ -1,6 +1,6 @@
 package Crixa::Queue;
 {
-  $Crixa::Queue::VERSION = '0.03';
+  $Crixa::Queue::VERSION = '0.04';
 }
 use 5.10.0;
 use Moose;
@@ -29,14 +29,22 @@ sub BUILD {
     $_[0]->_name($name);
 }
 
+sub check_for_message {
+    my ( $self, $args ) = @_;
+    $args //= {};
+    $self->_mq->get( $self->channel->id, $self->name, $args );
+}
+
+sub wait_for_message {
+    my ( $self, $args ) = @_;
+    my $msg;
+    do { $msg = $self->check_for_message($args); } until ( defined $msg );
+    return $msg;
+}
+
 sub handle_message {
     my ( $self, $handler, $args ) = @_;
-    my $msg;
-    $args //= {};
-    do {
-        $msg = $self->_mq->get( $self->channel->id, $self->name, $args );
-    } until ( defined $msg );
-
+    my $msg = $self->wait_for_message($args);
     for ($msg) { return $handler->($msg) }
     confess 'Something unusual happened.';
 }
@@ -57,7 +65,7 @@ Crixa::Queue
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 DESCRIPTION
 
@@ -77,8 +85,26 @@ Required.
 
 =head2 name
 
+The queue name.
+
 =head2 channel
 
+The channel this queue is configured for.
+
+=head2 check_for_message
+
+Checks the queue for a message. This doesn't block but instead will return
+undef if the queue is empty.
+
+=head2 wait_for_message
+
+Checks the queue for a message and blocks until one appears.
+
 =head2 handle_message
 
+Takes a callback and executes the callback when the next message appears in
+the queue.
+
 =head2 publish
+
+Send a new message to this queue.
